@@ -2,7 +2,7 @@
    Copyright (C) 2005 Christoph Cullmann <cullmann@kde.org>
    Copyright (C) 2002, 2003 Joseph Wenninger <jowenn@kde.org>
 
-   GUIClient partly based on ktoolbarhandler.cpp: Copyright (C) 2002 Simon Hausmann <hausmann@kde.org>
+   GUIClient partly based on tdetoolbarhandler.cpp: Copyright (C) 2002 Simon Hausmann <hausmann@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,12 +23,12 @@
 #include "katemdi.h"
 
 #include <kdebug.h>
-#include <kglobalsettings.h>
-#include <kapplication.h>
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdeglobalsettings.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 
 namespace KateMDI {
@@ -59,9 +59,9 @@ int Splitter::idAfter ( TQWidget * w ) const
 
 //BEGIN TOGGLETOOLVIEWACTION
 
-ToggleToolViewAction::ToggleToolViewAction ( const TQString& text, const KShortcut& cut, ToolView *tv,
+ToggleToolViewAction::ToggleToolViewAction ( const TQString& text, const TDEShortcut& cut, ToolView *tv,
                                              TQObject* parent, const char* name )
- : KToggleAction(text,cut,parent,name)
+ : TDEToggleAction(text,cut,parent,name)
  , m_tv(tv)
 {
   connect(this,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(slotToggled(bool)));
@@ -108,7 +108,7 @@ GUIClient::GUIClient ( MainWindow *mw )
   connect( m_mw->guiFactory(), TQT_SIGNAL( clientAdded( KXMLGUIClient * ) ),
            this, TQT_SLOT( clientAdded( KXMLGUIClient * ) ) );
 
-  if (actionCollection()->kaccel()==0)
+  if (actionCollection()->tdeaccel()==0)
     actionCollection()->setWidget(m_mw);
 
 
@@ -125,11 +125,11 @@ void GUIClient::registerToolView (ToolView *tv)
   TQString aname = TQString("kate_mdi_toolview_") + tv->id;
 
   // try to read the action shortcut
-  KShortcut sc;
-  KConfig *cfg = kapp->config();
+  TDEShortcut sc;
+  TDEConfig *cfg = kapp->config();
   TQString _grp = cfg->group();
   cfg->setGroup("Shortcuts");
-  sc = KShortcut( cfg->readEntry( aname, "" ) );
+  sc = TDEShortcut( cfg->readEntry( aname, "" ) );
   cfg->setGroup( _grp );
 }
 
@@ -181,8 +181,8 @@ bool ToolView::visible () const
 void ToolView::childEvent ( TQChildEvent *ev )
 {
   // set the widget to be focus proxy if possible
-  if (ev->inserted() && ev->child() && TQT_TQOBJECT(ev->child())->qt_cast(TQWIDGET_OBJECT_NAME_STRING))
-    setFocusProxy ((TQWidget *)(TQT_TQOBJECT(ev->child())->qt_cast(TQWIDGET_OBJECT_NAME_STRING)));
+  if (ev->inserted() && ev->child() && TQT_TQOBJECT(ev->child())->tqt_cast(TQWIDGET_OBJECT_NAME_STRING))
+    setFocusProxy ((TQWidget *)(TQT_TQOBJECT(ev->child())->tqt_cast(TQWIDGET_OBJECT_NAME_STRING)));
 
   TQVBox::childEvent (ev);
 }
@@ -223,7 +223,7 @@ void Sidebar::setSplitter (Splitter *sp)
 {
   m_splitter = sp;
   m_ownSplit = new Splitter ((sidebarPosition() == KMultiTabBar::Top || sidebarPosition() == KMultiTabBar::Bottom) ? Qt::Horizontal : Qt::Vertical, m_splitter);
-  m_ownSplit->setOpaqueResize( KGlobalSettings::opaqueResize() );
+  m_ownSplit->setOpaqueResize( TDEGlobalSettings::opaqueResize() );
   m_ownSplit->setChildrenCollapsible( false );
   m_splitter->setResizeMode( m_ownSplit, TQSplitter::KeepSize );
   m_ownSplit->hide ();
@@ -396,11 +396,11 @@ bool Sidebar::eventFilter(TQObject *obj, TQEvent *ev)
 
       if (w)
       {
-        KPopupMenu *p = new KPopupMenu (this);
+        TDEPopupMenu *p = new TDEPopupMenu (this);
 
         p->insertTitle(SmallIcon("view_remove"), i18n("Behavior"), 50);
 
-        p->insertItem(w->persistent ? SmallIconSet("window_nofullscreen") : SmallIconSet("window_fullscreen"), w->persistent ? i18n("Make Non-Persistent") : i18n("Make Persistent"), 10);
+        p->insertItem(w->persistent ? SmallIconSet("view-restore") : SmallIconSet("view-fullscreen"), w->persistent ? i18n("Make Non-Persistent") : i18n("Make Persistent"), 10);
 
         p->insertTitle(SmallIcon("move"), i18n("Move To"), 51);
 
@@ -411,10 +411,10 @@ bool Sidebar::eventFilter(TQObject *obj, TQEvent *ev)
           p->insertItem(SmallIconSet("forward"), i18n("Right Sidebar"),1);
 
 		if (sidebarPosition() != 2)
-          p->insertItem(SmallIconSet("up"), i18n("Top Sidebar"),2);
+          p->insertItem(SmallIconSet("go-up"), i18n("Top Sidebar"),2);
 
 		if (sidebarPosition() != 3)
-          p->insertItem(SmallIconSet("down"), i18n("Bottom Sidebar"),3);
+          p->insertItem(SmallIconSet("go-down"), i18n("Bottom Sidebar"),3);
 
         connect(p, TQT_SIGNAL(activated(int)),
               this, TQT_SLOT(buttonPopupActivate(int)));
@@ -470,7 +470,7 @@ class TmpToolViewSorter
     unsigned int pos;
 };
 
-void Sidebar::restoreSession (KConfig *config)
+void Sidebar::restoreSession (TDEConfig *config)
 {
   // get the last correct placed toolview
   unsigned int firstWrong = 0;
@@ -565,7 +565,7 @@ void Sidebar::restoreSession (KConfig *config)
     m_ownSplit->hide();
 }
 
-void Sidebar::saveSession (KConfig *config)
+void Sidebar::saveSession (TDEConfig *config)
 {
   // store the own splitter sizes
   TQValueList<int> s = m_ownSplit->sizes();
@@ -600,7 +600,7 @@ MainWindow::MainWindow (TQWidget* parentWidget, const char* name)
   m_sidebars[KMultiTabBar::Left] = new Sidebar (KMultiTabBar::Left, this, hb);
 
   m_hSplitter = new Splitter (Qt::Horizontal, hb);
-  m_hSplitter->setOpaqueResize( KGlobalSettings::opaqueResize() );
+  m_hSplitter->setOpaqueResize( TDEGlobalSettings::opaqueResize() );
 
   m_sidebars[KMultiTabBar::Left]->setSplitter (m_hSplitter);
 
@@ -610,7 +610,7 @@ MainWindow::MainWindow (TQWidget* parentWidget, const char* name)
   m_sidebars[KMultiTabBar::Top] = new Sidebar (KMultiTabBar::Top, this, vb);
 
   m_vSplitter = new Splitter (Qt::Vertical, vb);
-  m_vSplitter->setOpaqueResize( KGlobalSettings::opaqueResize() );
+  m_vSplitter->setOpaqueResize( TDEGlobalSettings::opaqueResize() );
 
   m_sidebars[KMultiTabBar::Top]->setSplitter (m_vSplitter);
 
@@ -742,7 +742,7 @@ bool MainWindow::hideToolView (ToolView *widget)
   return widget->sidebar()->hideWidget (widget);
 }
 
-void MainWindow::startRestore (KConfig *config, const TQString &group)
+void MainWindow::startRestore (TDEConfig *config, const TQString &group)
 {
   // first save this stuff
   m_restoreConfig = config;
@@ -822,7 +822,7 @@ void MainWindow::finishRestore ()
   m_restoreGroup = "";
 }
 
-void MainWindow::saveSession (KConfig *config, const TQString &group)
+void MainWindow::saveSession (TDEConfig *config, const TQString &group)
 {
   if (!config)
     return;
